<div align="center">

<h1>Use Python to build HTML.</h1>

<br>

<a href="https://github.com/jakebrehm/balisage"><img alt="GitHub last commit" src="https://img.shields.io/github/last-commit/jakebrehm/balisage?color=84B55A&logo=Git&logoColor=white&style=for-the-badge"></a>
<a href="https://github.com/jakebrehm/balisage/blob/main/license.txt"><img alt="GitHub license" src="https://img.shields.io/github/license/jakebrehm/balisage?color=84B55A&style=for-the-badge"></a>
<a href="https://codecov.io/gh/jakebrehm/balisage"><img alt="Codecov test coverage" src="https://img.shields.io/codecov/c/gh/jakebrehm/balisage?token=W6CWUDTYZC&color=84B55A&logo=codecov&logoColor=white&style=for-the-badge"></a>

<a href="https://pypi.org/project/balisage/"><img alt="PyPI page" src="https://img.shields.io/pypi/v/balisage?color=84B55A&logo=pypi&logoColor=white&style=for-the-badge"></a>
<a href="https://pypistats.org/packages/balisage"><img alt="PyPI downloads" src="https://img.shields.io/pypi/dm/balisage?color=84B55A&logo=pypi&logoColor=white&style=for-the-badge"></a>

<br>
</div>

<p align="center">
    <strong>balisage</strong> is a Python library that allows you to generate HTML using an intuitive and easy-to-use interface.
</p>
